<template>
  <gree-popup v-model="isShow" position="bottom" @hide="hidePopup">
    <div class="swupdn-set-popup">
      <!-- 标题 -->
      <div class="swupdn-set-popup-title" v-text="swupdn" />
      <div class="sweep-body">
        <gree-sweep-select
          :canvas-id="canvasId2"
          :canvas-width="width2"
          :canvas-height="height2"
          :origin="origin2"
          :select-default="selectDefault"
          @change="sweepUdChangeHandler"
          v-if="touchId === 2"
        >
        </gree-sweep-select>
      </div>
    </div>
  </gree-popup>
</template>

<script>
import { Header, SweepSelect, Toast, Popup } from 'gree-ui';
import { mapState, mapMutations, mapActions } from 'vuex';
import { showToast } from '@PluginInterface';
import { types } from '@/store/types';

export default {
  name: 'swupdn-picker-popup',
  components: {
    [Header.name]: Header,
    [Popup.name]: Popup,
    [SweepSelect.name]: SweepSelect
  },
  data() {
    return {
      isShow: false,
      selectDefault: ['0'],
      canvasId2: 'sector2',
      arr2: [],
      width2: Math.floor(window['lib'].flexible.rem / 0.15517),
      height2: Math.floor(window['lib'].flexible.rem / 0.11299),
      origin2: {
        x: Math.floor(window['lib'].flexible.rem / 0.16117),
        y: Math.floor(window['lib'].flexible.rem / 0.228),
        r: Math.floor(window['lib'].flexible.rem / 0.16949),
        startdeg: 224.5,
        opendeg: 18,
        count: 5
      },
      touchId: 2 // 1：左右扫风 2：上下扫风
    };
  },
  computed: {
    ...mapState('control', {
      SwUpDnPicker: state => state.popup.SwUpDnPicker,
      SwingLfRig: state => state.dataObject.SwingLfRig,
      SwUpDn: state => state.dataObject.SwUpDn,
      Pow: state => state.dataObject.Pow,
      selectSwingLfRig: state => {
        const swingLfRig = state.dataObject.SwingLfRig;
        const swingLfRigMap = [[], [], ['1'], ['2'], ['3'], ['4'], ['5']];
        return swingLfRigMap[swingLfRig];
      },
      selectSwUpDn: state => {
        const swUpDn = state.dataObject.SwUpDn;
        const swUpDnMap = [[], [], ['1'], ['2'], ['3'], ['4'], ['5']];
        return swUpDnMap[swUpDn];
      }
    }),
    routeName() {
      return this.$route.name;
    },
    swupdn() {
      return this.$language('btn.ConstUD');
    }
  },
  watch: {
    SwUpDnPicker: {
      handler(newVal) {
        this.isShow = newVal;
      },
      immediate: true
    },
    isShow(newVal) {
      !newVal && this.SetPopup({ SwUpDnPicker: false });
    },
    SwUpDn: {
      handler(newVal) {
        if (newVal) {
          this.selectDefault = this.selectSwUpDn;
          this.touchId = 0;
          this.$nextTick(() => (this.touchId = 2));
        }
      }
    },
    selectSwUpDn(newVal) {
      const touchId = this.$route.params.id;
      if (touchId === 2) {
        this.selectDefault = newVal;
        this.touchId = 0;
        this.$nextTick(() => (this.touchId = touchId));
      }
    },
    selectSwingLfRig(newVal) {
      const touchId = this.$route.params.id;
      if (touchId === 1) {
        this.selectDefault = newVal;
        this.touchId = 0;
        this.$nextTick(() => (this.touchId = touchId));
      }
    }
  },
  methods: {
    ...mapMutations({
      setDataObject: types.SET_DATA_OBJECT,
      setState: types.CONTROL_SET_STATE
    }),
    ...mapMutations('control', {
      SetPopup: 'SET_POPUP'
    }),
    ...mapActions({
      sendCtrl: types.SEND_CTRL
    }),
    hidePopup() {
      this.SetPopup({ SwUpDnPicker: false });
    },
    sweepLrChangeHandler(val) {
      const val2 = [];
      val.forEach(item => {
        val2.indexOf(item) === -1 ? val2.push(item) : '';
      });
      if (val2) {
        if (val2.length === 1) {
          this._setSweep({ SwingLfRig: Number(val2[0]) + 1, SmartWind: 0 });
        } else {
          // 刷新扇叶
          this.selectDefault = this.selectSwingLfRig;
          this.touchId = 0;
          this.$nextTick(() => (this.touchId = 1));
          try {
            val2.length && showToast(this.$language('sweep.sweep_lr_tips'), 0);
          } catch (err) {
            val2.length && Toast.info(`${this.$language('sweep.sweep_lr_tips')}`);
          }
        }
      }
    },
    sweepUdChangeHandler(val) {
      const val2 = [];
      val.forEach(item => {
        val2.indexOf(item) === -1 ? val2.push(item) : '';
      });
      if (val2) {
        if (val2.length === 1) {
          this._setSweep({ SwUpDn: Number(val2[0]) + 1, SmartWind: 0 });
        } else {
          // 刷新扇叶
          this.selectDefault = this.selectSwUpDn;
          this.touchId = 0;
          this.$nextTick(() => (this.touchId = 2));
          try {
            val2.length && showToast(this.$language('sweep.sweep_ud_tips2'), 0);
          } catch (err) {
            val2.length && Toast.info(`${this.$language('sweep.sweep_ud_tips2')}`);
          }
        }
      }
    },
    _setSweep(data) {
      if (!data) {
        return;
      }
      const storage = window.storage;
      const funcData = storage.get('funcData') || {};
      if (typeof data.SwingLfRig !== 'undefined' && this.SwingLfRig !== data.SwingLfRig) {
        this.setState({ ableSend: true });
        this.setDataObject({ ...data, SmartWind: 0 });
        this.sendCtrl({ ...data, SmartWind: 0 });
        funcData.ConstLR = data.SwingLfRig;
        storage.set('funcData', funcData);
      }

      if (typeof data.SwUpDn !== 'undefined' && this.SwUpDn !== data.SwUpDn) {
        this.setState({ ableSend: true });
        this.setDataObject({ ...data, SmartWind: 0, AntiDirectBlow: 0 });
        this.sendCtrl({ ...data, SmartWind: 0, AntiDirectBlow: 0 });
        funcData.ConstUD = data.SwUpDn;
        storage.set('funcData', funcData);
      }
    }
  }
};
</script>

<style lang="scss">
.swupdn-set-popup {
  width: 100%;
  background-color: #fff;
  &-title {
    padding-top: 30px;
    text-align: center;
    font-size: 50px;
  }
  .sweep-body {
    height: 950px;
  }
  canvas {
    position: relative;
    opacity: 0 !important;
  }
  .sweep-select-vertical {
    position: relative;
    margin: 0 auto;
    width: 656px;
    height: 940px;
    background-image: url('../../assets/img/functionBtn/sweep/sweep_vertical_new.png');
    background-repeat: no-repeat;
    background-size: 100%;
    background-position: center;

    .selected {
      position: absolute;
      background-repeat: no-repeat;
      background-size: 100%;
      background-position: center;
      pointer-events: none;

      &-1 {
        top: 28px;
        left: 62px;
        width: 571px;
        height: 450px;
        background-image: url('../../assets/img/functionBtn/sweep/sweep_vertical_1.png');
      }

      &-2 {
        top: 183px;
        left: 10px;
        width: 634px;
        height: 311px;
        background-image: url('../../assets/img/functionBtn/sweep/sweep_vertical_2.png');
      }

      &-3 {
        top: 373px;
        left: 0;
        width: 632px;
        height: 217px;
        background-image: url('../../assets/img/functionBtn/sweep/sweep_vertical_3.png');
      }

      &-4 {
        top: 468px;
        left: 8px;
        width: 625px;
        height: 305px;
        background-image: url('../../assets/img/functionBtn/sweep/sweep_vertical_4.png');
      }

      &-5 {
        top: 460px;
        left: 68px;
        width: 576px;
        height: 473px;
        background-image: url('../../assets/img/functionBtn/sweep/sweep_vertical_5.png');
      }
    }
  }
}
</style>
